@@ -6,7 +6,7 @@ require Exporter;
 
 use vars qw($VERSION @EXPORT_OK @ISA);
 
-$VERSION = '2.0';
+$VERSION = '2.01';
 @EXPORT_OK = qw(parsefile parsedommish);
 @ISA = qw(Exporter);
 
@@ -185,12 +185,8 @@ then you can query it thus:
 
     my $rsync = $document->externalprograms->rsync();
     my $rsyncbinary = $rsync->binary();
-    my $rsyncargs   = [
-        $rsync->shortargs->values(),
-        $srync->longargs->values()
-    ];
-    my $secondshortarg = $config->rsync->shortargs->arg(1);
-    my @shortargs      = $config->rsync->shortargs->arg('*');
+    my $secondshortarg = $rsync->shortargs->arg(1);
+    my @shortargs      = $rsync->shortargs->arg('*');
 
 The methods (eg C<binary>, C<rsync> etc) in the synopsis above are created
 using AUTOLOAD.  The AUTOLOADer first looks for an attribute with the
@@ -213,10 +209,6 @@ Nodes stringify to their contents if necessary, and can also be compared
 for string (in)equality.  Note that when stringifying, leading and
 trailing whitespace is removed.
 
-=head3 values
-
-Returns a list of the string contents of all child nodes.
-
 =cut
 
 my %regexps = (
@@ -581,15 +573,6 @@ sub AUTOLOAD {
         return (grep { $_->name() eq $wanted } @childnodes)[0];
     }
 }
-sub values {
-    my $self = shift;
-    my @values = ();
-    if(exists($self->{content}) && ref($self->{content}) eq 'ARRAY') {
-        push @values, __PACKAGE__->new($_)->_gettext()
-            foreach (@{$self->{content}});
-    }
-    return @values;
-}
 
 sub _gettext {
     my $self = shift;
